/*
        pc104 I/O address DIO24
*/
//#define ADDRESS_BASE            0x81008000		//DIO 24 - base address
//#define ADDRESS_BASE_IO         0x100			//DIO 24 - IO offet address
//#define ADDRESS_PORT_A          0x105			//DIO 24 - port a address(port a is output only)
//#define ADDRESS_PORT_B          0x106			//DIO 24 - port b address(port b set to output)
//#define ADDRESS_PORT_C          0x107			//DIO 24 - port c address(port c set to input)

#define ADDRESS_BASE            0x80005000		//new 3Z daughter board - base address
#define ADDRESS_LED_CFIG	0xa			//new 3Z daughter board - led config
#define ADDRESS_LED_OUTPUT	0x2			//new 3Z daughter board - LED outputs 15-0
#define ADDRESS_LED_INPUT	0x4			//new 3Z daughter board - LED outputs 15-0
#define ADDRESS_OUTPUT		0x6			//new 3Z daughter board - digital outputs 15-0
#define ADDRESS_INPUT		0x8			//new 3Z daughter board - digital inputs 15-0
#define ADDRESS_ADC_CFIG	0x10			//new 3Z daughter board - ADC config
#define ADDRESS_ADC_MASK	0x12			//new 3Z daughter board - ADC channel mask
#define ADDRESS_ADC_1		0x14			//new 3Z daughter board - ADC conversion value 1
#define ADDRESS_ADC_2		0x16			//new 3Z daughter board - ADC conversion value 2
#define ADDRESS_ADC_3		0x18			//new 3Z daughter board - ADC conversion value 3
#define ADDRESS_ADC_4		0x1a			//new 3Z daughter board - ADC conversion value 4

#define OUTPUT_PIN_ON		1			//output pin on
#define OUTPUT_PIN_OFF		0			//output pin off

#define ADDRESS_BASE            0x80005000		//new 3Z daughter board
//value 1 means pin has no input, and 0 means pin has input. same with output

/*
        common values for IO
*/
#define MAX_BIT_PER_DEVICE             16              //input and output pins count per device
#define MAX_NUM_LEVEL_INPUT_DEVICE      1               //input device count
#define MAX_NUM_LEVEL_OUTPUT_DEVICE     1               //output device count

/*
	Common
*/
#define CON_ENABLE			'E'		//Enabled
#define CON_DISABLE			'D'		//Disabled
#define FILE_CONFIG_OUTPUT_PATH		"/home/flexyard/flexyard/dfile/3Z_Config.dat"
#define FILE_CONFIG_OUTPUT_NAME		"3Z_Config.dat"
#define FILE_CONFIG_PATH		"/home/flexyard/flexyard/sysconfig/WebConfig.dat"
#define FILE_CONFIG_NAME		"WebConfig.dat"
#define FILE_CONFIG_UPLOAD_NAME		"cpData.dat"
#define FILE_CONFIG_UPLOAD_PATH		"/home/flexyard/flexyard/dfile/cpData.dat"
#define FILE_CONFIG_NODE_PATH		"/home/flexyard/flexyard/sysconfig/config_node.txt"
#define FILE_STORE_1			"/home/flexyard/flexyard/sysconfig/st1.txt"
#define FILE_STORE_2			"/home/flexyard/flexyard/sysconfig/st2.txt"
#define FILE_MESSAGE			"/home/flexyard/flexyard/sysconfig/3Z_MSG.dat"

/*
	Common Declaration
*/
#define RTN_NULL                0       
#define RTN_FAILURE             -1      
#define RTN_SUCCESS             -2      
#define RTN_WAIT                -3      
#define RTN_YES                 -4      
#define RTN_NO                  -5      
#define RTN_EMPTY               -6      
#define RTN_Q_FAILURE           -7      //queue failure

#define RTN_NO_PERMISSION		-9
#define DEBUG_LEVEL_ALL			0               //highest debug level
#define DEBUG_LEVEL_LOW			1
#define DEBUG_LEVEL_MEDIUM		2
#define DEBUG_LEVEL_NONE		9999
#define MAX_NUM_IO_QUEUE		(512 + 1)       //IoCenter queue

/*
	Declaration For Timer
*/
#define TIMER_IO_SEC			0		//seconds for IO timer
#define TIMER_IO_MSEC			100		//milliseconds for IO timer
#define SIZE_TEMP_STR           	120
#define TIMER_BTY_SEC			60		//seconds for battery detecting timer


/*
	Common Declaration For Mqueue
*/
#define SW_IO_QUEUE			"/swIoCenterQueue"	//queue name for SwitchIoCenter
#define SW_DISK_QUEUE			"/swDiskQueue"		//queue name for DiskCenter
#define TIMER_CENTER_QUEUE		"/timerCenterQueue"	//queue name for TimerCenter
#define MSG_MIN				0x6000
#define MSG_MAX				0x7FFF

/*
	Common Declaraion For DiskCenter
*/
#define MAX_NUM_DISK_MSG		51200			//max number for all message
#define MAX_SIZE_DISK_MSG		200			//max size for each message

/*
	Standard Inputs
*/
#define SPS_NONE			'N'		//Standard Proximity Switches:none
#define SPS_SINGLE			'S'		//Standard Proximity Switches:single
#define SPS_DOUBLE			'D'		//Standard Proximity Switches:double

/*
	Auxiliary Inputs
*/
#define APS_NONE			'N'		//Auxiliary Proximity Switches:none
#define APS_SINGLE			'S'		//Auxiliary Proximity Switches:single
#define APS_DOUBLE			'D'		//Auxiliary Proximity Switches:double

/*
	Outputs
*/

#define PIN_FUNCTION_NORMAL		'N'		//Pin Function: Normal(3 lights)
#define PIN_FUNCTION_SYNC		'S'		//Pin Function: Flash Synchronous(2 lights flash at same time)
#define PIN_FUNCTION_ALTER		'A'		//Pin Function: Flash Alternate(2 lights flash alternately)

#define STROBE_LIGHT_CONTINUOUS		'C'		//Strobe light status: Continuous
#define STROBE_LIGHT_FLASH		'F'		//Strobe light status: Flash

/*
	Timers
*/
#define SELE_RESTORE_DETECT_E		'E'		//Self restore detect input Lockout
#define SELE_RESTORE_DETECT_F		'F'		//Self restore detect one track
#define SELE_RESTORE_DETECT_G		'G'		//Self restore detect two tracks
#define SELE_RESTORE_DETECT_H		'H'		//Self restore detect three tracks
#define SELE_RESTORE_DETECT_B		'B'		//Self restore detect input both lockout and occupancy
#define SELF_RESTORE_NOR		'N'		//Self restore function to normal
#define SELF_RESTORE_REV		'R'		//Self restore function to reverse
#define SELF_RESTORE_NONE		'D'		//Self restore function disable

/*
	Special
*/
#define SWITCH_TYPE_SINGLE		'S'		//switch type single
#define SWITCH_TYPE_CROSSOVER_A		'A'		//switch type crossover A
#define SWITCH_TYPE_CROSSOVER_B		'B'		//switch type crossover B
#define PRESENCE_DETECT_ALL		'O'		//presence detection on switch A and B
#define PRESENCE_DETECT_A		'A'		//presence detection on switch A
#define PRESENCE_DETECT_B		'B'		//presence detection on switch B

/*
	IO pins
*/
#define MAX_NUM_IO			32		//max io number in dio24
#define MAX_TRIM_IO_NAME_LEN		50		//max device name length

/*
	Common value for debug
*/
#define DEBUG_LEVEL_ALL			0               //highest debug level
#define DEBUG_LEVEL_LOW			1
#define DEBUG_LEVEL_MEDIUM		2
#define DEBUG_LEVEL_NONE		9999

/*
	Common value for timer center
*/
#define MQUEUE_DEF_PRO			5		//currently 0 to 31, 0:lowest
#define TO_SW_IO_CENTER			1010		//message send to switch IoCenter
#define MAX_NODE_NAME_LEN		16		//max name length for nodeName
#define ONE_MILLISECOND			1000000		//1,000,000 nanoseconds = 1 millisecond
#define SEC_NANOSECOND			1000000000LL	//1,000,000,000(billion) nanoseconds = 1 sec

#define DEBUG_NONE			'N'
#define DEBUG_ON			'a'
#define DEBUG_OFF			'b'
#define TASK_NONE			0
#define TASK_NET_UDP			1
#define TASK_UI_CENTER			2
#define TASK_CSL			3
#define TASK_MSG_CENTER			4
#define TASK_TIME_CENTER		5
#define TASK_SIM_CENTER			6
#define TASK_AEI			7
#define TASK_DISK_CENTER		8
#define TASK_IO_CENTER			9       
#define TASK_TRIM_CENTER		10
#define TASK_NET_TRIM			11
#define TASK_TRIM_IO			12
#define TASK_NET_TCP			13
#define TASK_HYDRA_CENTER		14      
#define TASK_ROLL_TRAIN			90
#define TASK_ROLL_CUT			91
#define TASK_SW_IO_CENTER		92
#define TASK_TESTIO			100
